package kube

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Http.SensitiveSource

Sourcetype response = {
  1. status : int;
  2. reason : string;
  3. headers : (string * string) list;
  4. body : Secret.t;
}

A response whose body is owned by the caller and must be destroyed.

Sourceval request : ?cancel:Cancel.t -> ?headers:(string * string) list -> ?secret_headers:(string * Secret.t) list -> ?body:Secret.t -> ?max_body_bytes:int -> ?hardened:bool -> t -> meth -> string -> (response, string) result

Execute a request without placing sensitive header values, the request body, or the response body in ordinary OCaml strings. Secret inputs are borrowed for the synchronous call. The returned body is always protected, including for non-success status codes.

Sourceval request_once : ?cancel:Cancel.t -> ?headers:(string * string) list -> ?secret_headers:(string * Secret.t) list -> ?body:Secret.t -> ?max_body_bytes:int -> ?hardened:bool -> ?connect_timeout:float -> ?write_timeout:float -> ?response_header_timeout:float -> Config.t -> meth -> string -> (response, string) result
Sourcemodule For_testing : sig ... end